@@ -1,4 +1,9 @@
-import pickle
+
+# use cPickle when using python2 for better performance
+try:
+    import cPickle as pickle
+except ImportError:
+    import pickle
 import sys
 import random
 import os
@@ -32,7 +37,10 @@ class MarkovChain(object):
             with open(self.dbFilePath, 'rb') as dbfile:
                 self.db = pickle.load(dbfile)
         except IOError:
-            print('Database file not found, using empty database\n')
+            print('Database file not found, using empty database')
+            self.db = {}
+        except ValueError:
+            print('Database corrupt or unreadable, using empty database')
             self.db = {}
 
     def generateDatabase(self, textSample, sentenceSep='[.!?\n]'):
